Module structs

Module structs 

Structs

BodyItem
Holds the data and a pointer to the info
BodyItemInfo
Info for bodyitem: name,content type, file name if its a file, and value if urlencoded
Cookie
Encoding
EndPoint
Header
HttpServerError
Url

Enums

ContentType
EncodingType
RequestType
ResponseCode