Struct choki::Server

source ·
pub struct Server<T: Clone + Send + 'static> {
    pub max_content_length: usize,
    pub endpoints: Vec<EndPoint<T>>,
    pub static_endpoints: HashMap<String, String>,
    pub public_var: Option<T>,
    /* private fields */
}

Fields

max_content_length: usizeendpoints: Vec<EndPoint<T>>static_endpoints: HashMap<String, String>public_var: Option<T>

Implementations

source

impl<T: Clone + Send + 'static> Server<T>

source

pub fn new( max_content_length: Option<usize>, public_var: Option<T>, ) -> Server<T>

max_content_length is the max length of the request in bytes.

For example if the max is set to 1024 but the request is 1 000 000 it will close it straight away.

source

pub fn new_static( &mut self, path: String, folder: String, ) -> Result<(), HttpServerError>

Creates a new static url For example a folder named “images” on path /images every image in that folder will be exposed like “/images/example.png”

source

pub fn get( &mut self, path: String, handle: fn(req: Request, res: Response, public_var: Option<T>), ) -> Result<(), HttpServerError>

Creates a new GET endpoint

source

pub fn post( &mut self, path: String, handle: fn(req: Request, res: Response, public_var: Option<T>), ) -> Result<(), HttpServerError>

Creates a new POST endpoint

source

pub fn listen( &mut self, port: u32, address: Option<String>, ) -> Result<(), HttpServerError>

Starts listening on the given port.

source

pub fn lock()

Locks the thread from stoping (put it in the end of the main file to keep the server running);