Module structs
choki
1.1.19
Module structs
Module Items
Structs
Enums
In choki::
src
choki
::
src
Module
structs
Structs

Body
Item
Holds the data and a pointer to the info
Body
Item
Info
Info for bodyitem: name,content type, file name if its a file, and value if urlencoded
Cookie
Encoding
EndPoint
Header
Http
Server
Error
Url
Enums

Content
Type
Encoding
Type
Request
Type
Response
Code